get_collapsed_gene_model_exon: Get Collapsed Gene Model Exon
Description
This service returns the collapsed exons in the gene model of
the given gene. Gene-level and exon-level expression quantification were
based on the GENCODE annotation, collapsed to a single transcript model for
each gene using an algorithm developed by the GTEx analysis team.
By default, this service queries the models used by the latest GTEx release.