Retrieve eGenes (eQTL Genes).
This service returns eGenes (eQTL Genes) from the specified dataset.
eGenes are genes that have at least one significant cis-eQTL acting upon them.
Results may be filtered by tissue. By default, the service queries the latest GTEx release.
For each eGene, the results include the allelic fold change (log2AllelicFoldChange), p-value (pValue), p-value threshold (pValueThreshold), empirical p-value (empiricalPValue), and q-value (qValue).
The log2AllelicFoldChange is the allelic fold change (in log2 scale) of the most significant eQTL.
The pValue is the nominal p-value of the most significant eQTL.
The pValueThreshold is the p-value threshold used to determine whether a cis-eQTL for this gene is significant. For more details see https://gtexportal.org/home/documentationPage#staticTextAnalysisMethods.
The empiricalPValue is the beta distribution-adjusted empirical p-value from FastQTL.
The qValues were calculated based on the empirical p-values. A false discovery rate (FDR) threshold of <= 0.05 was applied to identify genes with a significant eQTL.
get_eqtl_genes(
tissueSiteDetailIds = NULL,
datasetId = "gtex_v8",
page = 0,
itemsPerPage = getOption("gtexr.itemsPerPage"),
.verbose = getOption("gtexr.verbose"),
.return_raw = FALSE
)A tibble. Or a list if .return_raw = TRUE.
Character vector of IDs for tissues of interest.
Can be GTEx specific IDs (e.g. "Whole_Blood"; use
get_tissue_site_detail() to see valid values) or Ontology IDs.
String. Unique identifier of a dataset. Usually includes a data source and data release. Options: "gtex_v8", "gtex_snrnaseq_pilot".
Integer (default = 0).
Integer (default = 250). Set globally to maximum value
100000 with options(list(gtexr.itemsPerPage = 100000)).
Logical. If TRUE (default), print paging information. Set
to FALSE globally with options(list(gtexr.verbose = FALSE)).
Logical. If TRUE, return the raw API JSON response.
Default = FALSE
Other Static Association Endpoints:
get_fine_mapping(),
get_independent_eqtl(),
get_multi_tissue_eqtls(),
get_significant_single_tissue_eqtls(),
get_significant_single_tissue_eqtls_by_location(),
get_significant_single_tissue_ieqtls(),
get_significant_single_tissue_isqtls(),
get_significant_single_tissue_sqtls(),
get_sqtl_genes()
if (FALSE) { # identical(Sys.getenv("IN_PKGDOWN"), "true")
get_eqtl_genes(c("Whole_Blood", "Artery_Aorta"))
}
Run the code above in your browser using DataLab