This service returns exons from all known transcripts of the given gene.
A versioned GENCODE ID is required to ensure that all exons are from a single gene.
A dataset ID or both GENCODE version and genome build must be provided.
Although annotated exons are not dataset dependent, specifying a dataset here is equivalent to specifying the GENCODE version and genome build used by that dataset.