powered by
This service allows the user to query the full Collapsed Gene Model Exon of a specific gene by gencode ID
GTEx Portal API documentation
get_full_get_collapsed_gene_model_exon( gencodeId, datasetId = "gtex_v8", page = 0, itemsPerPage = getOption("gtexr.itemsPerPage"), .verbose = getOption("gtexr.verbose"), .return_raw = FALSE )
A tibble. Or a list if .return_raw = TRUE.
.return_raw = TRUE
String. A Versioned GENCODE ID of a gene, e.g. "ENSG00000065613.9".
String. Unique identifier of a dataset. Usually includes a data source and data release. Options: "gtex_v8", "gtex_snrnaseq_pilot".
Integer (default = 0).
Integer (default = 250). Set globally to maximum value 100000 with options(list(gtexr.itemsPerPage = 100000)).
options(list(gtexr.itemsPerPage = 100000))
Logical. If TRUE (default), print paging information. Set to FALSE globally with options(list(gtexr.verbose = FALSE)).
TRUE
FALSE
options(list(gtexr.verbose = FALSE))
Logical. If TRUE, return the raw API JSON response. Default = FALSE
Other Datasets Endpoints: get_annotation(), get_collapsed_gene_model_exon(), get_downloads_page_data(), get_file_list(), get_functional_annotation(), get_linkage_disequilibrium_by_variant_data(), get_linkage_disequilibrium_data(), get_sample_datasets(), get_subject(), get_tissue_site_detail(), get_variant(), get_variant_by_location()
get_annotation()
get_collapsed_gene_model_exon()
get_downloads_page_data()
get_file_list()
get_functional_annotation()
get_linkage_disequilibrium_by_variant_data()
get_linkage_disequilibrium_data()
get_sample_datasets()
get_subject()
get_tissue_site_detail()
get_variant()
get_variant_by_location()
if (FALSE) { # identical(Sys.getenv("IN_PKGDOWN"), "true") get_full_get_collapsed_gene_model_exon(gencodeId = "ENSG00000203782.5") }
Run the code above in your browser using DataLab