powered by
Find genes that are partial or complete match of a gene_id
gene_id could be a gene symbol, a gencode ID, or an Ensemble ID
Gencode Version and Genome Build must be specified
GTEx Portal API documentation
get_gene_search( geneId, gencodeVersion = "v26", genomeBuild = "GRCh38/hg38", page = 0, itemsPerPage = getOption("gtexr.itemsPerPage"), .verbose = getOption("gtexr.verbose"), .return_raw = FALSE )
A tibble. Or a list if .return_raw = TRUE.
.return_raw = TRUE
String. A gene symbol, a gencode ID, or an Ensemble ID.
String (default = "v26"). GENCODE annotation release. Either "v26" or "v19".
String. Options: "GRCh38/hg38", "GRCh37/hg19". Default = "GRCh38/hg38".
Integer (default = 0).
Integer (default = 250). Set globally to maximum value 100000 with options(list(gtexr.itemsPerPage = 100000)).
options(list(gtexr.itemsPerPage = 100000))
Logical. If TRUE (default), print paging information. Set to FALSE globally with options(list(gtexr.verbose = FALSE)).
TRUE
FALSE
options(list(gtexr.verbose = FALSE))
Logical. If TRUE, return the raw API JSON response. Default = FALSE
Other Reference Genome Endpoints: get_exons(), get_genes(), get_genomic_features(), get_gwas_catalog_by_location(), get_neighbor_gene(), get_transcripts()
get_exons()
get_genes()
get_genomic_features()
get_gwas_catalog_by_location()
get_neighbor_gene()
get_transcripts()
if (FALSE) { # identical(Sys.getenv("IN_PKGDOWN"), "true") get_gene_search("CRP") }
Run the code above in your browser using DataLab