Find median transcript expression data of all known transcripts of a gene.
Returns median normalized expression in tissues of all known transcripts of a given gene.
Results may be filtered by dataset or tissue.
By default, this service queries the latest GTEx release.
get_median_transcript_expression(
gencodeIds,
datasetId = "gtex_v8",
tissueSiteDetailIds = NULL,
page = 0,
itemsPerPage = getOption("gtexr.itemsPerPage"),
.verbose = getOption("gtexr.verbose"),
.return_raw = FALSE
)A tibble. Or a list if .return_raw = TRUE.
A character vector of Versioned GENCODE IDs, e.g. c("ENSG00000132693.12", "ENSG00000203782.5").
String. Unique identifier of a dataset. Usually includes a data source and data release. Options: "gtex_v8", "gtex_snrnaseq_pilot".
Character vector of IDs for tissues of interest.
Can be GTEx specific IDs (e.g. "Whole_Blood"; use
get_tissue_site_detail() to see valid values) or Ontology IDs.
Integer (default = 0).
Integer (default = 250). Set globally to maximum value
100000 with options(list(gtexr.itemsPerPage = 100000)).
Logical. If TRUE (default), print paging information. Set
to FALSE globally with options(list(gtexr.verbose = FALSE)).
Logical. If TRUE, return the raw API JSON response.
Default = FALSE
Other Expression Data Endpoints:
get_clustered_median_exon_expression(),
get_clustered_median_gene_expression(),
get_clustered_median_junction_expression(),
get_clustered_median_transcript_expression(),
get_expression_pca(),
get_gene_expression(),
get_median_exon_expression(),
get_median_gene_expression(),
get_median_junction_expression(),
get_single_nucleus_gex(),
get_single_nucleus_gex_summary(),
get_top_expressed_genes()
if (FALSE) { # identical(Sys.getenv("IN_PKGDOWN"), "true")
get_median_transcript_expression(gencodeIds = "ENSG00000132693.12")
}
Run the code above in your browser using DataLab