Learn R Programming

gtexr (version 0.2.1)

get_significant_single_tissue_eqtls_by_location: Get Significant Single Tissue eQTLs By Location

Description

Find significant single tissue eQTLs using Chromosomal Locations.

  • This service returns precomputed significant single tissue eQTLs.

  • Results may be filtered by tissue, and/or dataset.

By default, the service queries the latest GTEx release. Since this endpoint is used to support a third party program on the portal, the return structure is different from other endpoints and is not paginated.

GTEx Portal API documentation

Usage

get_significant_single_tissue_eqtls_by_location(
  tissueSiteDetailId,
  start,
  end,
  chromosome,
  datasetId = "gtex_v8",
  .return_raw = FALSE
)

Value

A tibble. Or a list if .return_raw = TRUE.

Arguments

tissueSiteDetailId

String. The ID of the tissue of interest. Can be a GTEx specific ID (e.g. "Whole_Blood"; use get_tissue_site_detail() to see valid values) or an Ontology ID.

start

Integer.

end

Integer.

chromosome

String. One of "chr1", "chr2", "chr3", "chr4", "chr5", "chr6", "chr7", "chr8", "chr9", "chr10", "chr11", "chr12", "chr13", "chr14", "chr15", "chr16", "chr17", "chr18", "chr19", "chr20", "chr21", "chr22", "chrM", "chrX", "chrY".

datasetId

String. Unique identifier of a dataset. Usually includes a data source and data release. Options: "gtex_v8", "gtex_snrnaseq_pilot".

.return_raw

Logical. If TRUE, return the raw API JSON response. Default = FALSE

See Also

Other Static Association Endpoints: get_eqtl_genes(), get_fine_mapping(), get_independent_eqtl(), get_multi_tissue_eqtls(), get_significant_single_tissue_eqtls(), get_significant_single_tissue_ieqtls(), get_significant_single_tissue_isqtls(), get_significant_single_tissue_sqtls(), get_sqtl_genes()

Examples

Run this code
if (FALSE) { # identical(Sys.getenv("IN_PKGDOWN"), "true")
get_significant_single_tissue_eqtls_by_location(
  tissueSiteDetailId = "Artery_Aorta",
  start = 10000,
  end = 250000,
  chromosome = "chr11"
)
}

Run the code above in your browser using DataLab