if (FALSE) { # identical(Sys.getenv("IN_PKGDOWN"), "true")
# Search for one or more genes - returns a tibble with one row per tissue.
# Column "cellTypes" now contains a tibble of expression summary data, with
# one row for each cell type
get_single_nucleus_gex(gencodeIds = c(
"ENSG00000203782.5",
"ENSG00000132693.12"
))
# `excludeDataArray = FALSE` - expression values are stored under "celltypes"
# in an additional column called "data"
response <- get_single_nucleus_gex(
gencodeIds = "ENSG00000132693.12",
excludeDataArray = FALSE,
itemsPerPage = 2
)
response
# "cellTypes" contains a tibble of data with one row for each
# cell type e.g. for Breast_Mammary_Tissue
response$cellTypes[[2]]
# when `excludeDataArray = FALSE`, expression values are stored in "data"
# e.g. for Breast_Mammary_Tissue, Epithelial cell (luminal):
response$cellTypes[[2]]$data[[1]]
}
Run the code above in your browser using DataLab