Find top expressed genes for a specified tissue.
Returns top expressed genes for a specified tissue in a dataset, sorted by median expression.
When the optional parameter filterMtGene is set to true, mitochondrial genes will be excluded from the results. By default, this service queries the latest GTEx release.
get_top_expressed_genes(
tissueSiteDetailId,
datasetId = "gtex_v8",
filterMtGene = TRUE,
page = 0,
itemsPerPage = getOption("gtexr.itemsPerPage"),
.verbose = getOption("gtexr.verbose"),
.return_raw = FALSE
)A tibble. Or a list if .return_raw = TRUE.
String. The ID of the tissue of interest. Can be a
GTEx specific ID (e.g. "Whole_Blood"; use get_tissue_site_detail()
to see valid values) or an Ontology ID.
String. Unique identifier of a dataset. Usually includes a data source and data release. Options: "gtex_v8", "gtex_snrnaseq_pilot".
Logical. Exclude mitochondrial genes.
Integer (default = 0).
Integer (default = 250). Set globally to maximum value
100000 with options(list(gtexr.itemsPerPage = 100000)).
Logical. If TRUE (default), print paging information. Set
to FALSE globally with options(list(gtexr.verbose = FALSE)).
Logical. If TRUE, return the raw API JSON response.
Default = FALSE
Other Expression Data Endpoints:
get_clustered_median_exon_expression(),
get_clustered_median_gene_expression(),
get_clustered_median_junction_expression(),
get_clustered_median_transcript_expression(),
get_expression_pca(),
get_gene_expression(),
get_median_exon_expression(),
get_median_gene_expression(),
get_median_junction_expression(),
get_median_transcript_expression(),
get_single_nucleus_gex(),
get_single_nucleus_gex_summary()
if (FALSE) { # identical(Sys.getenv("IN_PKGDOWN"), "true")
get_top_expressed_genes(tissueSiteDetailId = "Artery_Aorta")
}
Run the code above in your browser using DataLab