powered by
Find all transcripts of a reference gene.
This service returns information about transcripts of the given versioned GENCODE ID.
A genome build and GENCODE version must be provided.
By default, this service queries the genome build and GENCODE version used by the latest GTEx release.
GTEx API Portal documentation
get_transcripts( gencodeId, gencodeVersion = "v26", genomeBuild = "GRCh38/hg38", page = 0, itemsPerPage = getOption("gtexr.itemsPerPage"), .verbose = getOption("gtexr.verbose"), .return_raw = FALSE )
A tibble. Or a list if .return_raw = TRUE.
.return_raw = TRUE
String. A Versioned GENCODE ID of a gene, e.g. "ENSG00000065613.9".
String (default = "v26"). GENCODE annotation release. Either "v26" or "v19".
String. Options: "GRCh38/hg38", "GRCh37/hg19". Default = "GRCh38/hg38".
Integer (default = 0).
Integer (default = 250). Set globally to maximum value 100000 with options(list(gtexr.itemsPerPage = 100000)).
options(list(gtexr.itemsPerPage = 100000))
Logical. If TRUE (default), print paging information. Set to FALSE globally with options(list(gtexr.verbose = FALSE)).
TRUE
FALSE
options(list(gtexr.verbose = FALSE))
Logical. If TRUE, return the raw API JSON response. Default = FALSE
Other Reference Genome Endpoints: get_exons(), get_gene_search(), get_genes(), get_genomic_features(), get_gwas_catalog_by_location(), get_neighbor_gene()
get_exons()
get_gene_search()
get_genes()
get_genomic_features()
get_gwas_catalog_by_location()
get_neighbor_gene()
if (FALSE) { # identical(Sys.getenv("IN_PKGDOWN"), "true") get_transcripts(gencodeId = "ENSG00000203782.5") }
Run the code above in your browser using DataLab