This service allows the user to query information about variants on a certain chromosome at a certain location.
get_variant_by_location(
start,
end,
chromosome,
sortBy = "pos",
sortDirection = "asc",
datasetId = "gtex_v8",
page = 0,
itemsPerPage = getOption("gtexr.itemsPerPage"),
.verbose = getOption("gtexr.verbose"),
.return_raw = FALSE
)A tibble. Or a list if .return_raw = TRUE.
Integer.
Integer.
String. One of "chr1", "chr2", "chr3", "chr4", "chr5", "chr6", "chr7", "chr8", "chr9", "chr10", "chr11", "chr12", "chr13", "chr14", "chr15", "chr16", "chr17", "chr18", "chr19", "chr20", "chr21", "chr22", "chrM", "chrX", "chrY".
String. Options: "sampleId", "ischemicTime", "aliquotId", "tissueSampleId", "hardyScale", "pathologyNotes", "ageBracket", "tissueSiteDetailId", "sex".
String. Options: "asc", "desc". Default = "asc".
String. Unique identifier of a dataset. Usually includes a data source and data release. Options: "gtex_v8", "gtex_snrnaseq_pilot".
Integer (default = 0).
Integer (default = 250). Set globally to maximum value
100000 with options(list(gtexr.itemsPerPage = 100000)).
Logical. If TRUE (default), print paging information. Set
to FALSE globally with options(list(gtexr.verbose = FALSE)).
Logical. If TRUE, return the raw API JSON response.
Default = FALSE
Other Datasets Endpoints:
get_annotation(),
get_collapsed_gene_model_exon(),
get_downloads_page_data(),
get_file_list(),
get_full_get_collapsed_gene_model_exon(),
get_functional_annotation(),
get_linkage_disequilibrium_by_variant_data(),
get_linkage_disequilibrium_data(),
get_sample_datasets(),
get_subject(),
get_tissue_site_detail(),
get_variant()
if (FALSE) { # identical(Sys.getenv("IN_PKGDOWN"), "true")
get_variant_by_location(
start = 153209600,
end = 153209700,
chromosome = "chr1"
)
}
Run the code above in your browser using DataLab